class Sth:

    def __init__(self):
        pass

    def find(self, arr):
        smallest = arr[0]
        smallest_index = 0

        for i in range(1, len(arr)):
            if arr[i] < smallest:
                smallest = arr[i]
                smallest_index = i
    
        return smallest_index

    def sort(self, arr):
        new_arr = []

        for i in range(len(arr)):
            smallest = self.find(arr)
            new_arr.append(arr.pop(smallest))
    
        return new_arr


from pywork.modules.sort_to_high import Sth

class Bs:

    def __init__ (self):
        pass

    def search(self, arr, item):
        low = 0
        high = len(arr) - 1
        list = Sth().sort(arr)

        while low <= high:
            mid = (low + high)
            guess = list[mid]

            if guess == item:
                return mid
            if guess > item:
                high = mid - 1
            else:
                low = mid + 1 

        return None


from setuptools import setup, find_packages
from os.path import join, dirname

setup(
    name='pyworked',
    version='0.0.8',
    packages=find_packages(),
    description="The easiest library for Python 3",
    long_description=open(join(dirname(__file__), 'README.txt')).read(),
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.8',
    ],
    keywords='library python pywork py work worked pyworked',
    url='https://github.com/Onebet163/pywork',
    author='Onebet163, UnAnsav',
    author_email='Yandancheats@gmail.com',
    license='MIT',
    include_package_data=True,
    zip_safe=False
)


class Stl:

    def __init__(self):
        pass

    def find(self, arr):
        biggest = arr[0] 
        biggest_index = 0

        for i in range(1, len(arr)):
            if arr[i] > biggest:
                biggest = arr[i]
                biggest_index = i

        return biggest_index

    def sort(self, arr):
        new_arr = []

        for i in range(len(arr)):
            biggest = self.find(arr)
            new_arr.append(arr.pop(biggest))

        return new_arr


# функция возращает True если число простое, и False если число составное
from math import sqrt


class Prime:
    def __init__(self):
        self.i = 2

    def check(self, n):

        self.limit = int(sqrt(n))

        if n < 2:
            return False
        elif n == 2:
            return True
        
        while self.i <= self.limit:
            if n % self.i == 0:
                return False
            self.i += 1

        return True





class Factorial:
    
    def __init__(self):
        self.factorial = 1

    def find(self, number):
        for i in range(2, number + 1):
            self.factorial *= i

        return(self.factorial)
        